==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/invocation/impl/ReturnStmtSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.invocation.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.body.ACT_SMTSet;
import io.ciera.tool.sql.ooaofooa.body.impl.ACT_SMTSetImpl;
import io.ciera.tool.sql.ooaofooa.invocation.ReturnStmt;
import io.ciera.tool.sql.ooaofooa.invocation.ReturnStmtSet;
import io.ciera.tool.sql.ooaofooa.value.ValueSet;
import io.ciera.tool.sql.ooaofooa.value.impl.ValueSetImpl;

import java.util.Arrays;
import java.util.List;


public class ReturnStmtSetImpl extends InstanceSet<ReturnStmtSet,ReturnStmt> implements ReturnStmtSet {

    // attributes
    @Override
    public void setStatement_ID( UniqueId ref_Statement_ID ) throws XtumlException {
        for ( ReturnStmt returnstmt : this ) returnstmt.setStatement_ID( ref_Statement_ID );
    }
    @Override
    public void setValue_ID( UniqueId ref_Value_ID ) throws XtumlException {
        for ( ReturnStmt returnstmt : this ) returnstmt.setValue_ID( ref_Value_ID );
    }


    // selections
    @Override
    public ACT_SMTSet R603_is_a_ACT_SMT() throws XtumlException {
        ACT_SMTSet act_smtset = new ACT_SMTSetImpl();
        for ( ReturnStmt returnstmt : this ) act_smtset.add( returnstmt.R603_is_a_ACT_SMT() );
        return act_smtset;
    }
    @Override
    public ValueSet R668_has_Value() throws XtumlException {
        ValueSet valueset = new ValueSetImpl();
        for ( ReturnStmt returnstmt : this ) valueset.add( returnstmt.R668_has_Value() );
        return valueset;
    }


    @Override
    public ReturnStmt nullElement() {
        return ReturnStmtImpl.EMPTY_RETURNSTMT;
    }

    @Override
    public ReturnStmtSet emptySet() {
      return new ReturnStmtSetImpl();
    }

    @Override
    public ReturnStmtSet value() {
        return this;
    }

    @Override
    public List<ReturnStmt> elements() {
        return Arrays.asList(toArray(new ReturnStmt[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/invocation/impl/ReturnStmtSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.invocation.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.body.ACT_SMTSet;
import io.ciera.tool.sql.ooaofooa.body.impl.ACT_SMTSetImpl;
import io.ciera.tool.sql.ooaofooa.invocation.ReturnStmt;
import io.ciera.tool.sql.ooaofooa.invocation.ReturnStmtSet;
import io.ciera.tool.sql.ooaofooa.value.ValueSet;
import io.ciera.tool.sql.ooaofooa.value.impl.ValueSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class ReturnStmtSetImpl extends InstanceSet<ReturnStmtSet,ReturnStmt> implements ReturnStmtSet {

    public ReturnStmtSetImpl() {
    }

    public ReturnStmtSetImpl(Comparator<? super ReturnStmt> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setStatement_ID( UniqueId ref_Statement_ID ) throws XtumlException {
        for ( ReturnStmt returnstmt : this ) returnstmt.setStatement_ID( ref_Statement_ID );
    }
    @Override
    public void setValue_ID( UniqueId ref_Value_ID ) throws XtumlException {
        for ( ReturnStmt returnstmt : this ) returnstmt.setValue_ID( ref_Value_ID );
    }


    // selections
    @Override
    public ACT_SMTSet R603_is_a_ACT_SMT() throws XtumlException {
        ACT_SMTSet act_smtset = new ACT_SMTSetImpl();
        for ( ReturnStmt returnstmt : this ) act_smtset.add( returnstmt.R603_is_a_ACT_SMT() );
        return act_smtset;
    }
    @Override
    public ValueSet R668_has_Value() throws XtumlException {
        ValueSet valueset = new ValueSetImpl();
        for ( ReturnStmt returnstmt : this ) valueset.add( returnstmt.R668_has_Value() );
        return valueset;
    }


    @Override
    public ReturnStmt nullElement() {
        return ReturnStmtImpl.EMPTY_RETURNSTMT;
    }

    @Override
    public ReturnStmtSet emptySet() {
      return new ReturnStmtSetImpl();
    }

    @Override
    public ReturnStmtSet emptySet(Comparator<? super ReturnStmt> comp) {
      return new ReturnStmtSetImpl(comp);
    }

    @Override
    public ReturnStmtSet value() {
        return this;
    }

    @Override
    public List<ReturnStmt> elements() {
        return Arrays.asList(toArray(new ReturnStmt[0]));
    }

}
